@@ -26,7 +26,10 @@ import ast
 logger = logging.getLogger(__name__)
 logger.addHandler(logging.NullHandler())
 
-
+class DeprecateAction(argparse.Action):
+    def __call__(self, parser, namespace, values, option_string=None):
+        warnings.warn("Argument %s is deprecated and is *ignored*." % self.option_strings)
+        delattr(namespace, self.dest)
 
 
 def prepare_batch(dl_batch, pred_batch,
@@ -289,10 +292,7 @@ def cli_predict(command, raw_args):
         if args.layer is None:
             pred_batch = model.predict_on_batch(batch['inputs'])
         else:
-            if isinstance(batch["inputs"], np.ndarray) and batch["inputs"].dtype == np.float64:
-                pred_batch = model.predict_activation_on_batch(batch['inputs'].astype(np.float32), layer=args.layer)
-            else:      
-                pred_batch = model.predict_activation_on_batch(batch['inputs'], layer=args.layer)
+            pred_batch = model.predict_activation_on_batch(batch['inputs'], layer=args.layer)
 
         # write out the predictions, metadata (, inputs, targets)
         output_batch = prepare_batch(batch, pred_batch, keep_inputs=args.keep_inputs, keep_metadata=args.keep_metadata)
